<?php

namespace Drupal\xsl_formatter\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the XSLT entity.
 *
 * @ConfigEntityType(
 *   id = "xslt",
 *   label = @Translation("XSL template"),
 *   label_collection = @Translation("XSL templates"),
 *   label_singular = @Translation("XSL template"),
 *   label_plural = @Translation("XSL templates"),
 *   label_count = @PluralTranslation(
 *     singular = "@count XSL template",
 *     plural = "@count XSL templates",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\xsl_formatter\Controller\XSLTListBuilder",
 *     "form" = {
 *       "add" = "Drupal\xsl_formatter\Form\XsltForm",
 *       "edit" = "Drupal\xsl_formatter\Form\XsltForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm",
 *     }
 *   },
 *   config_prefix = "xslt",
 *   admin_permission = "administer xsl templates",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "description" = "description",
 *     "xsl" = "xsl",
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "description",
 *     "xsl",
 *   },
 *   links = {
 *     "edit-form" = "/admin/structure/xslt/{xslt}",
 *     "delete-form" = "/admin/structure/xslt/{xslt}/delete",
 *     "collection" = "/admin/structure/xslt",
 *   }
 * )
 */
class Xslt extends ConfigEntityBase implements XsltInterface {

  /**
   * ID of the XSLT.
   *
   * @var string
   */
  public $id;

  /**
   * Label of the XSLT.
   *
   * @var string
   */
  public $label;

  /**
   * Description of the XSLT.
   *
   * @var string
   */
  public $description;

  /**
   * XSL content.
   *
   * @var string
   */
  public $xsl;

  /**
   * {@inheritDoc}
   */
  public function getXsl() {
    return $this->xsl;
  }

}
